@@ -172,7 +172,7 @@ def run_workflows_docker(
     workflow_name: Optional[str] = None,
     use_dag_id: Optional[str] = None,
 ) -> bool:
-    from phidata.app.devbox import DevboxArgs, default_devbox_name
+    from phidata.app.databox import DataboxArgs, default_databox_name
     from phidata.infra.docker.resource.types import (
         DockerResourceType,
         DockerContainer,
@@ -184,27 +184,27 @@ def run_workflows_docker(
     if docker_manager is None:
         raise DockerConfigException("DockerManager unavailable")
 
-    # Step 2: Check if a Devbox is available for running the Workflow
-    # If available get the DevboxArgs
-    devbox_app_name = target_app or docker_config.devbox_name or default_devbox_name
-    logger.debug(f"Using App: {devbox_app_name}")
-    devbox_app = docker_config.get_app_by_name(devbox_app_name)
-    if devbox_app is None:
-        print_error("Devbox not available")
+    # Step 2: Check if a Databox is available for running the Workflow
+    # If available get the DataboxArgs
+    databox_app_name = target_app or docker_config.databox_name or default_databox_name
+    logger.debug(f"Using App: {databox_app_name}")
+    databox_app = docker_config.get_app_by_name(databox_app_name)
+    if databox_app is None:
+        print_error("Databox not available")
         return False
-    devbox_app_args: Optional[Any] = devbox_app.args
-    # logger.debug(f"DevboxArgs: {devbox_app_args}")
-    if devbox_app_args is None or not isinstance(devbox_app_args, DevboxArgs):
-        print_error("DevboxArgs invalid")
+    databox_app_args: Optional[Any] = databox_app.args
+    # logger.debug(f"DataboxArgs: {databox_app_args}")
+    if databox_app_args is None or not isinstance(databox_app_args, DataboxArgs):
+        print_error("DataboxArgs invalid")
         return False
-    devbox_app_args = cast(DevboxArgs, devbox_app_args)
+    databox_app_args = cast(DataboxArgs, databox_app_args)
 
     # Step 3: Build the PathContext for the workflows.
     # NOTE: The PathContext uses directories relative to the
     # workspace_parent_container_path
     workspace_name = docker_config.workspace_root_path.stem
     workspace_root_container_path = Path(
-        devbox_app_args.workspace_parent_container_path
+        databox_app_args.workspace_parent_container_path
     ).joinpath(workspace_name)
     scripts_dir_container_path = workspace_root_container_path.joinpath(
         docker_config.scripts_dir
@@ -237,27 +237,27 @@ def run_workflows_docker(
     logger.debug(f"PathContext: {wf_path_context.json(indent=4)}")
 
     # Step 4: Get the container to run the Workflow
-    devbox_containers: Optional[
+    databox_containers: Optional[
         List[DockerResourceType]
     ] = docker_manager.get_resources(
-        name_filter=devbox_app_name, type_filter="DockerContainer"
+        name_filter=databox_app_name, type_filter="DockerContainer"
     )
-    # logger.debug(f"devbox_containers: {devbox_containers}")
-    if devbox_containers is None:
-        logger.error(f"DockerContainer:{devbox_app_name} not found")
+    # logger.debug(f"databox_containers: {databox_containers}")
+    if databox_containers is None:
+        logger.error(f"DockerContainer:{databox_app_name} not found")
         return False
-    if len(devbox_containers) > 1:
+    if len(databox_containers) > 1:
         print_warning(
             "Running commands in multiple containers is not yet supported. "
             + "Running in the first container. "
         )
-    devbox_container: DockerContainer = devbox_containers[0]
-    # logger.debug("devbox_container: ")
-    # logger.debug("Name: {}".format(devbox_container.name))
-    # logger.debug("Class: {}".format(devbox_container.__class__))
-    # logger.debug("Resource: {}".format(devbox_container))
+    databox_container: DockerContainer = databox_containers[0]
+    # logger.debug("databox_container: ")
+    # logger.debug("Name: {}".format(databox_container.name))
+    # logger.debug("Class: {}".format(databox_container.__class__))
+    # logger.debug("Resource: {}".format(databox_container))
     docker_client: DockerApiClient = docker_manager.docker_worker.docker_client
-    active_container: Optional[Container] = devbox_container.read(docker_client)
+    active_container: Optional[Container] = databox_container.read(docker_client)
     # logger.debug("active_container: {}".format(active_container.attrs))
     # logger.debug("Class: {}".format(active_container.__class__))
     # logger.debug("Type: {}".format(type(active_container)))
@@ -330,7 +330,7 @@ def run_data_products_docker(
     docker_config: DockerConfig,
     target_app: Optional[str] = None,
 ) -> bool:
-    from phidata.app.devbox import DevboxArgs, default_devbox_name
+    from phidata.app.databox import DataboxArgs, default_databox_name
     from phidata.infra.docker.resource.types import (
         DockerResourceType,
         DockerContainer,
@@ -342,26 +342,26 @@ def run_data_products_docker(
     if docker_manager is None:
         raise DockerConfigException("DockerManager unavailable")
 
-    # Step 2: Check if a DevboxApp is available for running the DataProduct
-    # If available get the DevboxAppArgs
-    devbox_app_name = target_app or docker_config.devbox_name or default_devbox_name
-    logger.debug(f"Using App: {devbox_app_name}")
-    devbox_app = docker_config.get_app_by_name(devbox_app_name)
-    if devbox_app is None:
-        print_error("Devbox not available")
+    # Step 2: Check if a DataboxApp is available for running the DataProduct
+    # If available get the DataboxAppArgs
+    databox_app_name = target_app or docker_config.databox_name or default_databox_name
+    logger.debug(f"Using App: {databox_app_name}")
+    databox_app = docker_config.get_app_by_name(databox_app_name)
+    if databox_app is None:
+        print_error("Databox not available")
         return False
-    devbox_app_args: Optional[Any] = devbox_app.args
-    # logger.debug(f"DevboxAppArgs: {devbox_app_args}")
-    if devbox_app_args is None or not isinstance(devbox_app_args, DevboxArgs):
-        print_error("DevboxArgs invalid")
+    databox_app_args: Optional[Any] = databox_app.args
+    # logger.debug(f"DataboxAppArgs: {databox_app_args}")
+    if databox_app_args is None or not isinstance(databox_app_args, DataboxArgs):
+        print_error("DataboxArgs invalid")
         return False
-    devbox_app_args = cast(DevboxArgs, devbox_app_args)
+    databox_app_args = cast(DataboxArgs, databox_app_args)
 
     # Step 3: Build the PathContext for the DataProducts.
     # NOTE: The PathContext uses directories relative to the workspace_parent_container_path
     workspace_name = docker_config.workspace_root_path.stem
     workspace_root_container_path = Path(
-        devbox_app_args.workspace_parent_container_path
+        databox_app_args.workspace_parent_container_path
     ).joinpath(workspace_name)
     scripts_dir_container_path = workspace_root_container_path.joinpath(
         docker_config.scripts_dir
@@ -394,26 +394,26 @@ def run_data_products_docker(
     logger.debug(f"PathContext: {dp_path_context.json(indent=4)}")
 
     # Step 4: Get the container to run the DataProduct
-    devbox_containers: Optional[
+    databox_containers: Optional[
         List[DockerResourceType]
     ] = docker_manager.get_resources(
-        name_filter=devbox_app_name, type_filter="DockerContainer"
+        name_filter=databox_app_name, type_filter="DockerContainer"
     )
-    if devbox_containers is None:
-        logger.error(f"DockerContainer:{devbox_app_name} not found")
+    if databox_containers is None:
+        logger.error(f"DockerContainer:{databox_app_name} not found")
         return False
-    if len(devbox_containers) > 1:
+    if len(databox_containers) > 1:
         print_info(
             "Running commands in multiple containers is not yet supported. "
             + "Running in the first container. "
         )
-    devbox_container: DockerContainer = devbox_containers[0]
-    # logger.debug("devbox_container: ")
-    # logger.debug("Name: {}".format(devbox_container.name))
-    # logger.debug("Class: {}".format(devbox_container.__class__))
-    # logger.debug("Resource: {}".format(devbox_container))
+    databox_container: DockerContainer = databox_containers[0]
+    # logger.debug("databox_container: ")
+    # logger.debug("Name: {}".format(databox_container.name))
+    # logger.debug("Class: {}".format(databox_container.__class__))
+    # logger.debug("Resource: {}".format(databox_container))
     docker_client: DockerApiClient = docker_manager.docker_worker.docker_client
-    active_container: Optional[Container] = devbox_container.read(docker_client)
+    active_container: Optional[Container] = databox_container.read(docker_client)
     # logger.debug("active_container: {}".format(active_container.attrs))
     # logger.debug("Class: {}".format(active_container.__class__))
     # logger.debug("Type: {}".format(type(active_container)))
@@ -455,7 +455,7 @@ def run_command_docker(
     docker_config: DockerConfig,
     target_app: Optional[str] = None,
 ) -> bool:
-    from phidata.app.devbox import DevboxArgs, default_devbox_name
+    from phidata.app.databox import DataboxArgs, default_databox_name
     from phidata.infra.docker.resource.types import (
         DockerResourceType,
         DockerContainer,
@@ -467,43 +467,43 @@ def run_command_docker(
     if docker_manager is None:
         raise DockerConfigException("DockerManager unavailable")
 
-    # Step 2: Check if a Devbox is available for running the DataProduct
-    # If available get the DevboxArgs
-    devbox_app_name = target_app or docker_config.devbox_name or default_devbox_name
-    logger.debug(f"Using App: {devbox_app_name}")
-    devbox_app = docker_config.get_app_by_name(devbox_app_name)
-    if devbox_app is None:
-        print_error("Devbox not available")
+    # Step 2: Check if a Databox is available for running the DataProduct
+    # If available get the DataboxArgs
+    databox_app_name = target_app or docker_config.databox_name or default_databox_name
+    logger.debug(f"Using App: {databox_app_name}")
+    databox_app = docker_config.get_app_by_name(databox_app_name)
+    if databox_app is None:
+        print_error("Databox not available")
         return False
-    devbox_app_args: Optional[Any] = devbox_app.args
-    # logger.debug(f"DevboxArgs: {devbox_app_args}")
-    if devbox_app_args is None or not isinstance(devbox_app_args, DevboxArgs):
-        print_error("DevboxArgs invalid")
+    databox_app_args: Optional[Any] = databox_app.args
+    # logger.debug(f"DataboxArgs: {databox_app_args}")
+    if databox_app_args is None or not isinstance(databox_app_args, DataboxArgs):
+        print_error("DataboxArgs invalid")
         return False
-    devbox_app_args = cast(DevboxArgs, devbox_app_args)
+    databox_app_args = cast(DataboxArgs, databox_app_args)
 
     # Step 3: Get the container to run the command
-    devbox_containers: Optional[
+    databox_containers: Optional[
         List[DockerResourceType]
     ] = docker_manager.get_resources(
-        name_filter=devbox_app_name, type_filter="DockerContainer"
+        name_filter=databox_app_name, type_filter="DockerContainer"
     )
-    # logger.debug(f"devbox_containers: {devbox_containers}")
-    if devbox_containers is None:
-        logger.error(f"DockerContainer:{devbox_app_name} not found")
+    # logger.debug(f"databox_containers: {databox_containers}")
+    if databox_containers is None:
+        logger.error(f"DockerContainer:{databox_app_name} not found")
         return False
-    if len(devbox_containers) > 1:
+    if len(databox_containers) > 1:
         print_info(
             "Running commands in multiple containers is not yet supported. "
             + "Running in the first container. "
         )
-    devbox_container: DockerContainer = devbox_containers[0]
-    # logger.debug("devbox_container: ")
-    # logger.debug("Name: {}".format(devbox_container.name))
-    # logger.debug("Class: {}".format(devbox_container.__class__))
-    # logger.debug("Resource: {}".format(devbox_container))
+    databox_container: DockerContainer = databox_containers[0]
+    # logger.debug("databox_container: ")
+    # logger.debug("Name: {}".format(databox_container.name))
+    # logger.debug("Class: {}".format(databox_container.__class__))
+    # logger.debug("Resource: {}".format(databox_container))
     docker_client: DockerApiClient = docker_manager.docker_worker.docker_client
-    active_container: Optional[Container] = devbox_container.read(docker_client)
+    active_container: Optional[Container] = databox_container.read(docker_client)
     # logger.debug("active_container: {}".format(active_container.attrs))
     # logger.debug("Class: {}".format(active_container.__class__))
     # logger.debug("Type: {}".format(type(active_container)))
